@@ -202,40 +202,6 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                             },
                             Err(_) => eprintln!("no response in 30 seconds")
                         }
-
-                        // match subscription.get_messages::<IdWrapper>().await {
-                        //     Ok(messages) => {
-                        //         for (result, ack_id) in messages {
-                        //             match result {
-                        //                 Ok(message) => {
-                        //                     println!("Received: {:?}", message);
-                        //                     match context_provider.new_context().await {
-                        //                         Ok(mut ctx) => {
-                        //                             if !ctx.start_transaction().await.is_ok() {
-                        //                                 continue;
-                        //                             }
-                        //                             let processing_result = process_handler(&internal_ctx, &mut ctx, &message.0).await;
-                        //                             if !processing_result.is_ok() {
-                        //                                 if !ctx.abort_transaction().await.is_ok() {
-                        //                                     // just log the failure to abort tx
-                        //                                     eprintln!("failed to commit tx");
-                        //                                 }
-                        //                                 continue;
-                        //                             }
-                        //                             if !ctx.commit_transaction().await.is_ok() {
-                        //                                 continue;
-                        //                             }
-                        //                             subscription.acknowledge_messages(vec![ack_id]).await;
-                        //                         }
-                        //                         Err(_) => {}
-                        //                     }
-                        //                 }
-                        //                 Err(e) => eprintln!("Failed to parse message: {}", e),
-                        //             }
-                        //         }
-                        //     }
-                        //     Err(e) => eprintln!("Failed to pull PubSub messages: {}", e)
-                        // }
                     }
                 });
             }
@@ -247,7 +213,11 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             pub async fn create_endpoint(
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 body: TypedBody<CreateParams>,
-            ) -> Result<HttpResponseOk<Checkout>, HttpError> {
+            ) -> Result<HttpResponseOk<Checkout<Payment<
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
+            >>>, HttpError> {
                 let params = body.into_inner();
                 let mut ctx = req_ctx
                     .context()
@@ -282,7 +252,11 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
                 body: TypedBody<AddOrRemoveItemParams>,
-            ) -> Result<HttpResponseOk<Checkout>, HttpError> {
+            ) -> Result<HttpResponseOk<Checkout<Payment<
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
+            >>>, HttpError> {
                 let path_params = path.into_inner();
                 let body_params = body.into_inner();
                 let mut ctx = req_ctx
@@ -318,7 +292,11 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
                 body: TypedBody<AddOrRemoveItemParams>,
-            ) -> Result<HttpResponseOk<Checkout>, HttpError> {
+            ) -> Result<HttpResponseOk<Checkout<Payment<
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
+            >>>, HttpError> {
                 let path_params = path.into_inner();
                 let body_params = body.into_inner();
                 let mut ctx = req_ctx
@@ -353,7 +331,11 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             pub async fn confirm_items_endpoint(
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
-            ) -> Result<HttpResponseOk<Checkout>, HttpError> {
+            ) -> Result<HttpResponseOk<Checkout<Payment<
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
+            >>>, HttpError> {
                 let path_params = path.into_inner();
                 let mut ctx = req_ctx
                     .context()
@@ -389,7 +371,11 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
                 body: TypedBody<Contact>,
-            ) -> Result<HttpResponseOk<Checkout>, HttpError> {
+            ) -> Result<HttpResponseOk<Checkout<Payment<
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
+            >>>, HttpError> {
                 let path_params = path.into_inner();
                 let contact = body.into_inner();
                 let mut ctx = req_ctx
@@ -425,7 +411,11 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
                 body: TypedBody<Address>,
-            ) -> Result<HttpResponseOk<Checkout>, HttpError> {
+            ) -> Result<HttpResponseOk<Checkout<Payment<
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
+            >>>, HttpError> {
                 let path_params = path.into_inner();
                 let shipping_address = body.into_inner();
                 let mut ctx = req_ctx
@@ -461,7 +451,11 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
                 body: TypedBody<FulfillmentTypeSelection>,
-            ) -> Result<HttpResponseOk<Checkout>, HttpError> {
+            ) -> Result<HttpResponseOk<Checkout<Payment<
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
+            >>>, HttpError> {
                 let path_params = path.into_inner();
                 let fulfillment_type = body.into_inner();
                 let mut ctx = req_ctx
@@ -497,7 +491,11 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
                 body: TypedBody<<super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs>,
-            ) -> Result<HttpResponseOk<Checkout>, HttpError> {
+            ) -> Result<HttpResponseOk<Checkout<Payment<
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
+            >>>, HttpError> {
                 let path_params = path.into_inner();
                 let args = body.into_inner();
                 let mut ctx = req_ctx
@@ -533,7 +531,11 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
                 req_ctx: Arc<RequestContext<ServerContext>>,
                 path: Path<IdParam>,
                 body: TypedBody<<super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs>,
-            ) -> Result<HttpResponseOk<Checkout>, HttpError> {
+            ) -> Result<HttpResponseOk<Checkout<Payment<
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PrivateData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::PublicData,
+                <super::#context_type_name #ty_static_generics as PaymentProcessor>::ProcessArgs
+            >>>, HttpError> {
                 let path_params = path.into_inner();
                 let args = body.into_inner();
                 let internal_ctx = req_ctx
